"""sappgen - Simple App Generator Python

    >>> sappgen [options] <project_name> <app_name>

See https://github.com/aayushuppal/sappgen for more information
"""

# Version of sappgen package
__version__ = "1.0.7"

from .sappgen import process, main
